@@ -5,7 +5,7 @@ from cricket.model import Project
 class UnittestProject(Project):
 
     def __init__(self, options=None):
-        super(Project, self).__init__()
+        super(UnittestProject, self).__init__()
 
     def discover_commandline(self):
         "Command line: Discover all available tests in a project."
@@ -13,4 +13,7 @@ class UnittestProject(Project):
 
     def execute_commandline(self, labels):
         "Return the command line to execute the specified test labels"
-        return [sys.executable, '-m', 'cricket.unittest.executor'] + labels
\ No newline at end of file
+        args = [sys.executable, '-m', 'cricket.unittest.executor']
+        if self.coverage:
+            args.append('--coverage')
+        return args + labels
\ No newline at end of file
