@@ -2,13 +2,24 @@
 
 This is the "View" of the MVC world.
 """
-
+import subprocess
 from Tkinter import *
 from tkFont import *
 from ttk import *
 import tkMessageBox
 import webbrowser
 
+# Check for the existence of coverage and duvet
+try:
+    import coverage
+    try:
+        import duvet
+    except ImportError:
+        duvet = None
+except ImportError:
+    coverage = None
+    duvet = None
+
 from tkreadonly import ReadOnlyText
 
 from cricket import VERSION, NUM_VERSION
@@ -140,6 +151,9 @@ class MainWindow(object):
         self.menu_test = Menu(self.menubar)
         self.menubar.add_cascade(menu=self.menu_test, label='Test')
 
+        self.menu_beeware = Menu(self.menubar)
+        self.menubar.add_cascade(menu=self.menu_beeware, label='BeeWare')
+
         self.menu_help = Menu(self.menubar)
         self.menubar.add_cascade(menu=self.menu_help, label='Help')
 
@@ -153,6 +167,8 @@ class MainWindow(object):
         self.menu_test.add_command(label='Run selected tests', command=self.cmd_run_selected)
         self.menu_test.add_command(label='Re-run failed tests', command=self.cmd_rerun)
 
+        self.menu_beeware.add_command(label='Open Duvet...', command=self.cmd_open_duvet, state=DISABLED if duvet is None else ACTIVE)
+
         self.menu_help.add_command(label='Open Documentation', command=self.cmd_cricket_docs)
         self.menu_help.add_command(label='Open Cricket project page', command=self.cmd_cricket_page)
         self.menu_help.add_command(label='Open Cricket on GitHub', command=self.cmd_cricket_github)
@@ -185,6 +201,19 @@ class MainWindow(object):
         self.rerun_button = Button(self.toolbar, text='Re-run', command=self.cmd_rerun, state=DISABLED)
         self.rerun_button.grid(column=3, row=0)
 
+        self.coverage = StringVar()
+        self.coverage_checkbox = Checkbutton(self.toolbar, text='Generate coverage',
+                                    command=self.on_coverageChange, variable=self.coverage)
+        self.coverage_checkbox.grid(column=4, row=0)
+
+        # If coverage is available, enable it by default.
+        # Otherwise, disable the widget
+        if coverage:
+            self.coverage.set('1')
+        else:
+            self.coverage.set('0')
+            self.coverage_checkbox.configure(state=DISABLED)
+
         self.toolbar.columnconfigure(0, weight=0)
         self.toolbar.rowconfigure(0, weight=1)
 
@@ -488,6 +517,9 @@ class MainWindow(object):
         # Listen for any status updates on nodes in the tree.
         TestMethod.bind('status_update', self.on_nodeStatusUpdate)
 
+        # Update the project to make sure coverage status matches the GUI
+        self.on_coverageChange()
+
     ######################################################
     # TK Main loop
     ######################################################
@@ -542,6 +574,13 @@ class MainWindow(object):
         if not self.executor or not self.executor.is_running:
             self.run(status=set(TestMethod.FAILING_STATES))
 
+    def cmd_open_duvet(self, event=None):
+        "Command: Open Duvet"
+        try:
+            subprocess.Popen('duvet')
+        except Exception, e:
+            tkMessageBox.showerror('Unable to start Duvet: %s' % e)
+
     def cmd_cricket_page(self):
         "Show the Cricket project page"
         webbrowser.open_new('http://pybee.org/cricket/')
@@ -736,6 +775,10 @@ class MainWindow(object):
                         has_children = True
                     node = node.parent
 
+    def on_coverageChange(self):
+        "Event handler: when the coverage checkbox has been toggled"
+        self.project.coverage = self.coverage.get() == '1'
+
     def on_testProgress(self):
         "Event handler: a periodic update to poll the runner for output, generating GUI updates"
         if self.executor and self.executor.poll():
